@@ -9,15 +9,13 @@ Documento = []
 
 #_print_Symbol
 
-from ArtemioADaySolvers.latemix import *
-
 def Inicializar(n):
   global DatosList,Orden,Estilo
   
   DatosList = [[sympy.pi,3.14]]
   Orden = 8
   Documento = []
-  return DatosList
+  return DatosList,Orden
   
 def search(symbolo):
   for c_element in DatosList:
@@ -154,6 +152,8 @@ def S(c_componente):#Guardar
 def R(string):
   display(IPython.display.Latex(string))  
 
+from ArtemioADaySolvers.latemix import *
+
 def E(expr,color ="black"):
   print("")
   if isinstance(expr,sympy.core.relational.Equality):#Si tenemos una igualdad
